==> pluxml_5.4.orig.tar.gz: PluXml-5.4/core/lang/ro/core.php <==
<?php

$LANG = array(

'L_LANGUE'						=> 'Română',

# common
'L_PLUXML_VERSION'				=> 'Pluxml version',
'L_HOMEPAGE'					=> 'Home',
'L_UNCLASSIFIED'				=> 'Neclasificat',
'L_INFO_PHP_VERSION'			=> 'Versiune php',
'L_INFO_MAGIC_QUOTES'			=> 'Starea "magic quotes"',
'L_INFO_CHARSET'				=> 'encoding',

# index.php
'L_ERR_THEME_NOTFOUND'			=> 'Tema principala este gasita',
'L_ERR_FILE_NOTFOUND'			=> 'Fisierul tinta nu este gasit ',
'L_ERR_PAGE_NOT_FOUND'			=> 'Pagina nu a fost gasit',

# class.plx.date.php
'L_SHORT_JANUARY'				=> 'ian',
'L_SHORT_FEBRUARY'				=> 'feb',
'L_SHORT_MARCH'					=> 'mar',
'L_SHORT_APRIL'					=> 'apr',
'L_SHORT_MAY'					=> 'mai',
'L_SHORT_JUNE'					=> 'iunie',
'L_SHORT_JULY'					=> 'iulie',
'L_SHORT_AUGUST'				=> 'aug',
'L_SHORT_SEPTEMBER'				=> 'sept',
'L_SHORT_OCTOBER'				=> 'oct',
'L_SHORT_NOVEMBER'				=> 'noem',
'L_SHORT_DECEMBER'				=> 'dec',
'L_JANUARY'						=> 'ianuarie',
'L_FEBRUARY'					=> 'februarie',
'L_MARCH'						=> 'martie',
'L_APRIL'						=> 'aprilie',
'L_MAY'							=> 'mai',
'L_JUNE'						=> 'iunie',
'L_JULY'						=> 'iulie',
'L_AUGUST'						=> 'august',
'L_SEPTEMBER'					=> 'septembrie',
'L_OCTOBER'						=> 'octombrie',
'L_NOVEMBER'					=> 'noiembrie',
'L_DECEMBER'					=> 'decembrie',
'L_MONDAY'						=> 'luni',
'L_TUESDAY'						=> 'marti',
'L_WEDNESDAY'					=> 'miercuri',
'L_THURSDAY'					=> 'joi',
'L_FRIDAY'						=> 'vineri',
'L_SATURDAY'					=> 'sambata',
'L_SUNDAY'						=> 'duminica',

# class.plx.capcha.php
'L_LAST'						=> 'ultima',
'L_FIRST'						=> 'prima',
'L_SECOND'						=> 'a doua',
'L_THIRD'						=> 'a treia',
'L_FOURTH'						=> 'a patra',
'L_FIFTH'						=> 'a cincia',
'L_SIXTH'						=> 'a şasea',
'L_SEVENTH'						=> 'a şaptea',
'L_EIGTH'						=> 'a opta',
'L_NINTH'						=> 'a noua',
'L_TENTH'						=> 'a zecea',
'L_NTH'							=> 'lea',
'L_CAPCHA_QUESTION'				=> 'Care este <span class="capcha-letter">%s</span> litera a cuvantului <span class="capcha-word">%s</span> ?',

# class.plx.utils.php
'L_WRITE_ACCESS'				=> '%s are acces de scriere',
'L_WRITE_NOT_ACCESS'			=> '%s nu are acces de scriere sau nu există',
'L_MODREWRITE_AVAILABLE'		=> 'Apache URL Rewriting module mod_rewrite este disponibil',
'L_MODREWRITE_NOT_AVAILABLE'	=> 'Apache URL Rewriting module mod_rewrite nu este disponibil',
'L_LIBGD_INSTALLED'				=> 'Biblioteca GD este instalată',
'L_LIBGD_NOT_INSTALLED'			=> 'Biblioteca GD nu este instalată',
'L_MAIL_AVAILABLE'				=> 'Functia  de a trimite e-mail disponibilă',
'L_MAIL_NOT_AVAILABLE'			=> 'Functia  de a trimite e-mail nu este disponibilă',

# class.plx.motor.php
'L_FILE_VERSION_REQUIRED'		=> 'Fisierul "%sversion" este necesar pentru functionarea PluXml',
'L_ARTICLE_NO_TAG'				=> 'Nici un articol pentru acest cuvant cheie !',
'L_UNKNOWN_CATEGORY'			=> 'Aceasta categorie nu exista!',
'L_NO_ARTICLE_PAGE'				=> 'Nu exista articole pentru aceasta pagina !',
'L_UNKNOWN_ARTICLE'				=> 'Acest produs nu exista sau nu-i  sunt mai !',
'L_COM_IN_MODERATION'			=> 'Comentariul este moderat de catre administratorul acestui site',
'L_UNKNOWN_STATIC'				=> 'Aceasta pagina nu exista sau nu-i sunt mai !',
'L_DOCUMENT_NOT_FOUND'			=> 'Documentul mentionat nu a fost gasit',
'L_NEWCOMMENT_ERR'				=> 'O eroare este intalnit in timp ce publicarea acestui comentariu',
'L_NEWCOMMENT_FIELDS_REQUIRED'	=> 'Va multumim completati toate campurile obligatorii',
'L_NEWCOMMENT_ERR_ANTISPAM'		=> 'SPAM de verificare a esuat',

# class.plx.show.php

'L_HTTPENCODING'				=> 'Compresie %s activata',
'L_PAGETITLE_ARCHIVES'			=> 'Arhive',
'L_PAGETITLE_TAG'				=> 'Tag',
'L_NO_CATEGORY'					=> 'nicio categorie',
'L_CATEGORY'					=> 'categoria',
'L_CATEGORIES'					=> 'categorii',
'L_NO_ARTICLE'					=> 'nici un articol',
'L_ARTICLE'						=> 'articolul',
'L_ARTICLES'					=> 'articole',
'L_ARTAUTHOR_UNKNOWN'			=> 'necunoscut',
'L_ARTTAGS_NONE'				=> 'nimic',
'L_ARTCHAPO'					=> 'Continuati lectura #art_title',
'L_ARTFEED_RSS_CATEGORY'		=> 'RSS Feed Elementele din această categorie',
'L_ARTFEED_RSS_TAG'				=> 'RSS Feed Elementele din această etichetă',
'L_ARTFEED_RSS'					=> 'Articole RSS Feed',
'L_NO_COMMENT'					=> 'nici un comentariu',
'L_COMMENT'						=> 'comentariu',
'L_COMMENTS'					=> 'comentarii',
'L_COMFEED_RSS_ARTICLE'			=> 'RSS feed pentru comentarii pe acest articol',
'L_COMFEED_RSS'					=> 'Comentarii RSS feed',
'L_STATICCONTENT_INPROCESS'		=> 'Aceasta pagina este in curs de elaborare',
'L_SAID'						=> 'a spus',

'L_PAGINATION_FIRST_TITLE'		=> 'Du-te la prima pagina',
'L_PAGINATION_FIRST'			=> '«',
'L_PAGINATION_PREVIOUS_TITLE'	=> 'Pagina anterioara',
'L_PAGINATION_PREVIOUS'			=> 'Anterioare',
'L_PAGINATION_NEXT_TITLE'		=> 'Pagina urmatoare',
'L_PAGINATION_NEXT'				=> 'Urmatorul',
'L_PAGINATION_LAST_TITLE'		=> 'Du-te la ultima pagina',
'L_PAGINATION_LAST'				=> '»',
'L_PAGINATION'					=> 'pagina %s din %s',

'L_PAGEBLOG_TITLE'				=> 'Blog',

# class.plx.feed.php
'L_FEED_NO_PRIVATE_URL'			=> 'URL-uri private nu au fost initializate in parametrii dvs. de administrare !',
'L_FEED_COMMENTS'				=> 'Comentarii',
'L_FEED_ONLINE_COMMENTS'		=> 'Comentarii online',
'L_FEED_OFFLINE_COMMENTS'		=> 'Comentarii offline',
'L_FEED_WRITTEN_BY'				=> 'Scris de',

);
?>

==> pluxml_5.5.orig.tar.gz: PluXml-5.5/core/lang/ro/core.php <==
<?php

$LANG = array(

'L_LANGUE'						=> 'Română',

'L_DATE_CREATION'				=> 'Data crearii',
'L_DATE_UPDATE'					=> 'Data de actualizare',

# common
'L_PLUXML_VERSION'				=> 'Pluxml version',
'L_HOMEPAGE'					=> 'Home',
'L_UNCLASSIFIED'				=> 'Neclasificat',
'L_INFO_PHP_VERSION'			=> 'Versiune php',
'L_INFO_MAGIC_QUOTES'			=> 'Starea "magic quotes"',
'L_INFO_CHARSET'				=> 'encoding',

# index.php
'L_ERR_THEME_NOTFOUND'			=> 'Tema principala este gasita',
'L_ERR_FILE_NOTFOUND'			=> 'Fisierul tinta nu este gasit ',
'L_ERR_PAGE_NOT_FOUND'			=> 'Pagina nu a fost gasit',

# class.plx.date.php
'L_SHORT_JANUARY'				=> 'ian',
'L_SHORT_FEBRUARY'				=> 'feb',
'L_SHORT_MARCH'					=> 'mar',
'L_SHORT_APRIL'					=> 'apr',
'L_SHORT_MAY'					=> 'mai',
'L_SHORT_JUNE'					=> 'iunie',
'L_SHORT_JULY'					=> 'iulie',
'L_SHORT_AUGUST'				=> 'aug',
'L_SHORT_SEPTEMBER'				=> 'sept',
'L_SHORT_OCTOBER'				=> 'oct',
'L_SHORT_NOVEMBER'				=> 'noem',
'L_SHORT_DECEMBER'				=> 'dec',
'L_JANUARY'						=> 'ianuarie',
'L_FEBRUARY'					=> 'februarie',
'L_MARCH'						=> 'martie',
'L_APRIL'						=> 'aprilie',
'L_MAY'							=> 'mai',
'L_JUNE'						=> 'iunie',
'L_JULY'						=> 'iulie',
'L_AUGUST'						=> 'august',
'L_SEPTEMBER'					=> 'septembrie',
'L_OCTOBER'						=> 'octombrie',
'L_NOVEMBER'					=> 'noiembrie',
'L_DECEMBER'					=> 'decembrie',
'L_MONDAY'						=> 'luni',
'L_TUESDAY'						=> 'marti',
'L_WEDNESDAY'					=> 'miercuri',
'L_THURSDAY'					=> 'joi',
'L_FRIDAY'						=> 'vineri',
'L_SATURDAY'					=> 'sambata',
'L_SUNDAY'						=> 'duminica',

# class.plx.capcha.php
'L_LAST'						=> 'ultima',
'L_FIRST'						=> 'prima',
'L_SECOND'						=> 'a doua',
'L_THIRD'						=> 'a treia',
'L_FOURTH'						=> 'a patra',
'L_FIFTH'						=> 'a cincia',
'L_SIXTH'						=> 'a şasea',
'L_SEVENTH'						=> 'a şaptea',
'L_EIGTH'						=> 'a opta',
'L_NINTH'						=> 'a noua',
'L_TENTH'						=> 'a zecea',
'L_NTH'							=> 'lea',
'L_CAPCHA_QUESTION'				=> 'Care este <span class="capcha-letter">%s</span> litera a cuvantului <span class="capcha-word">%s</span> ?',

# class.plx.utils.php
'L_WRITE_ACCESS'				=> '%s are acces de scriere',
'L_WRITE_NOT_ACCESS'			=> '%s nu are acces de scriere sau nu există',
'L_MODREWRITE_AVAILABLE'		=> 'Apache URL Rewriting module mod_rewrite este disponibil',
'L_MODREWRITE_NOT_AVAILABLE'	=> 'Apache URL Rewriting module mod_rewrite nu este disponibil',
'L_LIBGD_INSTALLED'				=> 'Biblioteca GD este instalată',
'L_LIBGD_NOT_INSTALLED'			=> 'Biblioteca GD nu este instalată',
'L_MAIL_AVAILABLE'				=> 'Functia  de a trimite e-mail disponibilă',
'L_MAIL_NOT_AVAILABLE'			=> 'Functia  de a trimite e-mail nu este disponibilă',

# class.plx.motor.php
'L_ARTICLE_NO_TAG'				=> 'Nici un articol pentru acest cuvant cheie !',
'L_UNKNOWN_CATEGORY'			=> 'Aceasta categorie nu exista!',
'L_NO_ARTICLE_PAGE'				=> 'Nu exista articole pentru aceasta pagina !',
'L_UNKNOWN_ARTICLE'				=> 'Acest produs nu exista sau nu-i  sunt mai !',
'L_COM_IN_MODERATION'			=> 'Comentariul este moderat de catre administratorul acestui site',
'L_UNKNOWN_STATIC'				=> 'Aceasta pagina nu exista sau nu-i sunt mai !',
'L_DOCUMENT_NOT_FOUND'			=> 'Documentul mentionat nu a fost gasit',
'L_NEWCOMMENT_ERR'				=> 'O eroare este intalnit in timp ce publicarea acestui comentariu',
'L_NEWCOMMENT_FIELDS_REQUIRED'	=> 'Va multumim completati toate campurile obligatorii',
'L_NEWCOMMENT_ERR_ANTISPAM'		=> 'SPAM de verificare a esuat',

# class.plx.show.php

'L_HTTPENCODING'				=> 'Compresie %s activata',
'L_PAGETITLE_ARCHIVES'			=> 'Arhive',
'L_PAGETITLE_TAG'				=> 'Tag',
'L_NO_CATEGORY'					=> 'nicio categorie',
'L_CATEGORY'					=> 'categoria',
'L_CATEGORIES'					=> 'categorii',
'L_NO_ARTICLE'					=> 'nici un articol',
'L_ARTICLE'						=> 'articolul',
'L_ARTICLES'					=> 'articole',
'L_ARTAUTHOR_UNKNOWN'			=> 'necunoscut',
'L_ARTTAGS_NONE'				=> 'nimic',
'L_ARTCHAPO'					=> 'Continuati lectura #art_title',
'L_ARTFEED_RSS_CATEGORY'		=> 'RSS Feed Elementele din această categorie',
'L_ARTFEED_RSS_TAG'				=> 'RSS Feed Elementele din această etichetă',
'L_ARTFEED_RSS'					=> 'Articole RSS Feed',
'L_NO_COMMENT'					=> 'nici un comentariu',
'L_COMMENT'						=> 'comentariu',
'L_COMMENTS'					=> 'comentarii',
'L_COMFEED_RSS_ARTICLE'			=> 'RSS feed pentru comentarii pe acest articol',
'L_COMFEED_RSS'					=> 'Comentarii RSS feed',
'L_STATICCONTENT_INPROCESS'		=> 'Aceasta pagina este in curs de elaborare',
'L_SAID'						=> 'a spus',

'L_PAGINATION_FIRST_TITLE'		=> 'Du-te la prima pagina',
'L_PAGINATION_FIRST'			=> '«',
'L_PAGINATION_PREVIOUS_TITLE'	=> 'Pagina anterioara',
'L_PAGINATION_PREVIOUS'			=> 'Anterioare',
'L_PAGINATION_NEXT_TITLE'		=> 'Pagina urmatoare',
'L_PAGINATION_NEXT'				=> 'Urmatorul',
'L_PAGINATION_LAST_TITLE'		=> 'Du-te la ultima pagina',
'L_PAGINATION_LAST'				=> '»',
'L_PAGINATION'					=> 'pagina %s din %s',

'L_PAGEBLOG_TITLE'				=> 'Blog',

# class.plx.feed.php
'L_FEED_NO_PRIVATE_URL'			=> 'URL-uri private nu au fost initializate in parametrii dvs. de administrare !',
'L_FEED_COMMENTS'				=> 'Comentarii',
'L_FEED_ONLINE_COMMENTS'		=> 'Comentarii online',
'L_FEED_OFFLINE_COMMENTS'		=> 'Comentarii offline',
'L_FEED_WRITTEN_BY'				=> 'Scris de',

);
?>
